# Tweet Timing

## Time Zones Matter

- Twitter doesn't allow you to segment your tweets by time zone
- If you have cloase followers on East Coast don't tweet after 6 pm
    - they'll unfollow or mute your vibe/beep notifcation
- If you're on East Coast, don't tweet before 11 am
    - they'll unfollow or mute you
- I fyou want to catch people on their commute
    - repeat tweet at 4 different times approx 1 hr apart.
    - accept that you'll be limitted to one time zone of active followers (unmuted)

## Resources

- Recomendation engine explanation by creator of Tumblr back end
    - [Ben Frederickson](http://www.benfrederickson.com/distance-metrics/)
